@@ -1,5 +1,7 @@
 import pandas as pd
 def topsis(df,weights,impacts):
+    df1=pd.DataFrames(columns=df.columns)
+    df1=df.copy()
     vjp=[]
     vjn=[]
     r=df.shape[0]
@@ -23,6 +25,6 @@ def topsis(df,weights,impacts):
     for i in range(r):
         df.loc[i,'sj-']=sum((df.iloc[i,1:c]-vjn)**2)**0.5
 # print(df)
-    df['Topsis Score']=round(df['sj-']/(df['sj+']+df['sj-']),2)
-    df['Rank']=df['Topsis Score'].rank(ascending=False).astype('int')
-    return df
\ No newline at end of file
+    df1['Topsis Score']=round(df['sj-']/(df['sj+']+df['sj-']),2)
+    df1['Rank']=df1['Topsis Score'].rank(ascending=False).astype('int')
+    return df1
\ No newline at end of file
